@@ -36,11 +36,10 @@
 #include <QResizeEvent>
 #include <QSvgRenderer>
 #include <QStandardPaths>
-#include <QTimerEvent>
 
 #include <math.h>
 
-KToggleAction *MyMainView::pauseAction = 0;
+KToggleAction *MyMainView::pauseAction = nullptr;
 
 static struct
  {
@@ -53,7 +52,7 @@ static struct
      { ID_MINE1, "mine_red%1"},
      { ID_MINE2, "mine_blue%1"},
      { ID_MINEEXPLO, "mineex%1"},
-     { 0, 0}
+     { 0, nullptr}
  };
 
 MyMainView::MyMainView(QWidget *parent)
@@ -63,8 +62,8 @@ MyMainView::MyMainView(QWidget *parent)
 {
    int i,p;
    setMinimumSize(600,400);
-   random.setSeed(0);
-   QPixmap backgr(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral(MV_BACKGROUND)));
+   random.seed(QRandomGenerator::global()->generate());
+   QPixmap backgr(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral(MV_BACKGROUND)));
 
    field.setBackgroundBrush(QBrush(backgr));
    view.setCacheMode(QGraphicsView::CacheBackground);
@@ -84,7 +83,7 @@ MyMainView::MyMainView(QWidget *parent)
       minePut[p]=false;
    }
 
-   svgrender = new QSvgRenderer(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral(MV_SVG_FILE)));
+   svgrender = new QSvgRenderer(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral(MV_SVG_FILE)));
 
    sun=new SunSprite(svgrender,QStringLiteral( MV_SUN ));
    field.addItem(sun);
@@ -113,7 +112,7 @@ MyMainView::MyMainView(QWidget *parent)
    }
 
    waitForStart=false;
-   textSprite=0;
+   textSprite = nullptr;
    readConfig();
 }
 
@@ -367,7 +366,7 @@ void MyMainView::pause()
 
       waitForStart=true;
       QAbstractEventDispatcher::instance()->unregisterTimers(this);
-      emit setStatusText(i18n(" paused "), IDS_PAUSE);
+      Q_EMIT setStatusText(i18n(" paused "), IDS_PAUSE);
    }
 }
 
@@ -375,8 +374,8 @@ void MyMainView::resume()
 {
    waitForStart=false;
    timerID=startTimer(Options::refreshTime());
-   emit(setStatusText(QLatin1String( "" ),IDS_PAUSE));
-   emit(setStatusText(QLatin1String( "" ),IDS_MAIN));
+   Q_EMIT setStatusText(QLatin1String( "" ),IDS_PAUSE);
+   Q_EMIT setStatusText(QLatin1String( "" ),IDS_MAIN);
 }
 
 void MyMainView::start( )
@@ -389,8 +388,8 @@ void MyMainView::start( )
    {
       waitForStart = false;
       timerID=startTimer(Options::refreshTime());
-      emit(setStatusText(QLatin1String( "" ),IDS_PAUSE));
-      emit(setStatusText(QLatin1String( "" ),IDS_MAIN));
+      Q_EMIT setStatusText(QLatin1String( "" ),IDS_PAUSE);
+      Q_EMIT setStatusText(QLatin1String( "" ),IDS_MAIN);
       pauseAction->setEnabled( true );
       pauseAction->setChecked( false );
    }
@@ -464,7 +463,7 @@ void MyMainView::newRound()
    double mx,my;
    int i;
 
-   timeToNextPowerup=random.getDouble() * config.powerupRefreshTime;
+   timeToNextPowerup=random.bounded(config.powerupRefreshTime);
    qDeleteAll(powerups);
    powerups.clear();
 
@@ -488,8 +487,8 @@ void MyMainView::newRound()
       ship[i]->setHitPoints(Options::startHitPoints(i));
       ship[i]->stop(false);
       ship[i]->setExplosion(-1);
-      emit(energy(i,(int)ship[i]->getEnergy()));
-      emit(hitPoints(i,ship[i]->getHitPoints()));
+      Q_EMIT energy(i,(int)ship[i]->getEnergy());
+      Q_EMIT hitPoints(i,ship[i]->getHitPoints());
       bulletShot[i]=false;
       qDeleteAll(*bullets[i]);
       bullets[i]->clear();
@@ -516,14 +515,14 @@ void MyMainView::newRound()
    {
       textSprite->hide();
       delete textSprite;
-      textSprite=0;
+      textSprite = nullptr;
    }
    //field.update();
 
    QString str = i18n("Press %1 to start",
                   actionCollection->action(QStringLiteral("game_start"))->shortcut().toString(QKeySequence::NativeText));
-   emit(setStatusText(str,IDS_MAIN));
-   emit(setStatusText( QLatin1String( "" ), IDS_PAUSE ));
+   Q_EMIT setStatusText(str,IDS_MAIN);
+   Q_EMIT setStatusText( QLatin1String( "" ), IDS_PAUSE );
    stop( );
 }
 
@@ -533,7 +532,7 @@ void MyMainView::newGame()
    for(i=0;i<2;i++)
    {
       ship[i]->setWins(0);
-      emit(wins(i,0));
+      Q_EMIT wins(i,0);
    }
    newRound();
 }
@@ -557,9 +556,9 @@ void MyMainView::timerEvent(QTimerEvent *event)
             {
                textSprite->hide();
                delete textSprite;
-               textSprite=0;
+               textSprite = nullptr;
             }
-            textSprite=new QGraphicsSimpleTextItem(0);
+            textSprite = new QGraphicsSimpleTextItem(nullptr);
             field.addItem(textSprite);
 	    // FIXME
            // textSprite->setTextFlags(Qt::AlignCenter);
@@ -575,7 +574,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
                   textSprite->setText(i18n("blue player won the round"));
                   w=ship[1]->getWins()+1;
                   ship[1]->setWins(w);
-                  emit(wins(1,w));
+                  Q_EMIT wins(1,w);
                }
             }
             else
@@ -583,14 +582,14 @@ void MyMainView::timerEvent(QTimerEvent *event)
                textSprite->setText(i18n("red player won the round"));
                w=ship[0]->getWins()+1;
                ship[0]->setWins(w);
-               emit(wins(0,w));
+               Q_EMIT wins(0,w);
             }
             // must do this after setting text, because length is unknown until now
             textSprite->setPos(QPointF((width()-textSprite->boundingRect().width()) / 2,height()/2-90));
 
             QString str = i18n("Press %1 for new round",
                           actionCollection->action(QStringLiteral("game_start"))->shortcut().toString(QKeySequence::NativeText));
-            emit(setStatusText(str,IDS_MAIN));
+            Q_EMIT setStatusText(str,IDS_MAIN);
             stop( );
          }
       }
@@ -615,7 +614,7 @@ void MyMainView::timerEvent(QTimerEvent *event)
 
 void MyMainView::moveShips()
 {
-   int i,nf,olde;
+   int i,olde;
    double nx,ny,en,nr;
    BulletSprite *bullet;
    MineSprite *mine;
@@ -637,24 +636,23 @@ void MyMainView::moveShips()
                                          config.gamespeed);
 
 
-         if(!playerIsAi&&playerKeyPressed[i][PlayerKeyRight]
-            || playerIsAi&&ai[i]->rotateRight())
+         if ((!playerIsAi && playerKeyPressed[i][PlayerKeyRight]) ||
+             (playerIsAi && ai[i]->rotateRight()))
             ship[i]->rotateRight(config.rotationEnergyNeed,
                                  config.rotationSpeed);
 
-         if(!playerIsAi&&playerKeyPressed[i][PlayerKeyLeft]
-            || playerIsAi&&ai[i]->rotateLeft())
+         if (!(playerIsAi && playerKeyPressed[i][PlayerKeyLeft]) ||
+             (playerIsAi && ai[i]->rotateLeft()))
             ship[i]->rotateLeft(config.rotationEnergyNeed,
                                 config.rotationSpeed);
 
          en=ship[i]->getEnergy();
          nr=ship[i]->getRotation();
 
-         nf = 0;
          nx=cos(nr);
          ny=sin(nr);
-         if ( ((!playerIsAi && playerKeyPressed[i][PlayerKeyAcc])
-             || playerIsAi&&ai[i]->accelerate())
+         if (((!playerIsAi && playerKeyPressed[i][PlayerKeyAcc]) ||
+              (playerIsAi && ai[i]->accelerate()))
 	     && (en>config.energyNeed) )
          {
             en-=config.energyNeed;
@@ -678,13 +676,13 @@ void MyMainView::moveShips()
          ship[i]->forward(config.gamespeed);
 
              //Bullets and Mines
-         if(!playerIsAi&&playerKeyPressed[i][PlayerKeyShot]
-            ||playerIsAi&&ai[i]->shootBullet())
+         if ((!playerIsAi && playerKeyPressed[i][PlayerKeyShot]) ||
+             (playerIsAi && ai[i]->shootBullet()))
          {
             if((en>config.shotEnergyNeed) && (!ship[i]->reloadsBullet()))
             {
                if(bullets[i]->count() <
-                  (config.maxBullets+ship[i]->getBulletPowerups()))
+                  (static_cast<int>(config.maxBullets) + ship[i]->getBulletPowerups()))
                {
                   ship[i]->bullet(config.bulletReloadTime);
                   en-=config.shotEnergyNeed;
@@ -706,13 +704,13 @@ void MyMainView::moveShips()
                }
             }
          }
-         if(!Options::playerIsAi(i)&&playerKeyPressed[i][PlayerKeyMine]
-            || Options::playerIsAi(i)&&ai[i]->layMine())
+         if ((!Options::playerIsAi(i) && playerKeyPressed[i][PlayerKeyMine]) ||
+             (Options::playerIsAi(i) && ai[i]->layMine()))
          {
             if((en>config.mineEnergyNeed) && (!ship[i]->reloadsMine()))
             {
                if(mines[i]->count() <
-                  (config.maxMines+ship[i]->getMinePowerups()))
+                  (static_cast<int>(config.maxMines) + ship[i]->getMinePowerups()))
                {
                   ship[i]->mine(config.mineReloadTime);
                   en-=config.mineEnergyNeed;
@@ -723,7 +721,6 @@ void MyMainView::moveShips()
 		     mine=new MineSprite(svgrender,animation[ID_MINE2],animation[ID_MINEEXPLO],i,
                                       config.mineActivateTime,config.mineFuel);
 		  field.addItem(mine);
-		  QPointF p;
 		  mine->setPos(ship[i]->mapToScene(ship[i]->center()));
                   // move mine to center
                   mine->moveBy(-mine->center().x(),-mine->center().y());
@@ -736,7 +733,7 @@ void MyMainView::moveShips()
          }
          ship[i]->setEnergy(en);
          if(olde!=(int)en)
-            emit(energy(i,(int)en));
+            Q_EMIT energy(i,(int)en);
       }
    }
 }
@@ -841,15 +838,15 @@ void MyMainView::calculatePowerups()
    if(timeToNextPowerup<0)
    {
       int type,x,y;
-      timeToNextPowerup= random.getDouble() * config.powerupRefreshTime;
-      type= random.getLong(PowerupSprite::PowerupNum);
+      timeToNextPowerup= random.bounded(config.powerupRefreshTime);
+      type= random.bounded(PowerupSprite::PowerupNum);
       sp=new PowerupSprite(svgrender,powerupelements[type],type,
                            config.powerupLifeTime);
       field.addItem(sp);
       do
       {
-         x = random.getLong(width()-40)+20;
-         y = random.getLong(height()-40)+20;
+         x = random.bounded(width()-40)+20;
+         y = random.bounded(height()-40)+20;
       }
       while(((x-width()/2)*(x-width()/2)+(y-height()/2)*(y-height()/2))<(50*50));
       sp->setPos(QPointF(x,y));
@@ -860,9 +857,8 @@ void MyMainView::calculatePowerups()
 
 void MyMainView::collisions()
 {
-   int pl,hp,op,oldhp[2],ohp;
+   int pl,hp,oldhp[2],ohp;
    QList<QGraphicsItem *> unexact;
-   QGraphicsItem *sprite;
    BulletSprite *bullet;
    MineSprite *mine;
    ExplosionSprite *expl;
@@ -882,8 +878,7 @@ void MyMainView::collisions()
 	 unexact = ship[pl]->collidingItems(Qt::IntersectsItemBoundingRect);
          oldhp[pl]=hp=ship[pl]->getHitPoints();
          hitlist.clear();
-	 foreach (sprite, unexact)
-         {
+	 for (QGraphicsItem *sprite : qAsConst(unexact)) {
             if((sprite->type()!=S_EXPLOSION)
                && !((sprite->type()!=S_SUN)&&(ship[pl]->getHitPoints()==0)))
                if(ship[pl]->collidesWithItem(sprite,Qt::IntersectsItemShape))
@@ -891,8 +886,7 @@ void MyMainView::collisions()
                      hitlist.append(sprite);
          }
 
-         foreach (sprite, hitlist)
-         {
+         for (QGraphicsItem *sprite : qAsConst(hitlist)) {
             switch(sprite->type())
             {
                case S_SUN:
@@ -913,7 +907,7 @@ void MyMainView::collisions()
                   if(ohp>0)
                   {
                      s->setHitPoints(ohp-hp-config.shipDamage);
-                     emit(hitPoints(s->getPlayerNumber(),s->getHitPoints()));
+                     Q_EMIT hitPoints(s->getPlayerNumber(),s->getHitPoints());
                      ndx[0]=((1-EPSILON)*ship[0]->xVelocity()+(1+EPSILON)*ship[1]->xVelocity())/2.0;
                      ndy[0]=((1-EPSILON)*ship[0]->yVelocity()+(1+EPSILON)*ship[1]->yVelocity())/2.0;
                      ndx[1]=((1-EPSILON)*ship[1]->xVelocity()+(1+EPSILON)*ship[0]->xVelocity())/2.0;
@@ -977,8 +971,7 @@ void MyMainView::collisions()
             unexact.clear();
             unexact=mine->collidingItems(Qt::IntersectsItemBoundingRect);
             hitlist.clear();
-	    foreach (sprite, unexact)
-            {
+	    for (QGraphicsItem *sprite : qAsConst(unexact)) {
                if(sprite->type()==S_BULLET)
                   if(mine->collidesWithItem(sprite))
                      if(!hitlist.contains(sprite))
@@ -987,8 +980,7 @@ void MyMainView::collisions()
             if(!hitlist.isEmpty())
             {
                mine->explode();
-	       foreach (QGraphicsItem *item, hitlist)
-               {
+	       for (QGraphicsItem *item : qAsConst(hitlist)) {
                   // FIXME: why does it crash with qgraphicsitem_cast?
 		  bullet = static_cast<BulletSprite*>(item);// qgraphicsitem_cast<BulletSprite*>(item);
 //                   bullets[bullet->getPlayerNumber()]->removeRef(bullet);
@@ -1003,8 +995,7 @@ void MyMainView::collisions()
    hitlist.clear();
    unexact.clear();
    unexact=sun->collidingItems(Qt::IntersectsItemBoundingRect);
-   foreach (sprite, unexact)
-   {
+   for (QGraphicsItem *sprite : qAsConst(unexact)) {
       switch(sprite->type())
       {
          case S_BULLET:
@@ -1021,8 +1012,7 @@ void MyMainView::collisions()
       }
    }
 
-   foreach (sprite, hitlist)
-   {
+   for (QGraphicsItem *sprite : qAsConst(hitlist)) {
       switch(sprite->type())
       {
          case S_BULLET:
@@ -1045,10 +1035,9 @@ void MyMainView::collisions()
    {
       hp=ship[pl]->getHitPoints();
       if(hp!=oldhp[pl])
-         emit(hitPoints(pl,hp));
+         Q_EMIT hitPoints(pl,hp);
       if((hp==0)&&(ship[pl]->getExplosion()<0))
       {
-         op=(pl+1)%2;
          ship[pl]->setExplosion((int)(EXPLOSION_TIME/config.gamespeed));
 	 expl = new ExplosionSprite(svgrender,animation[ID_EXPLOSION],ship[pl]);
 	 field.addItem(expl);
